@@ -15,6 +15,7 @@ $VERSION = '1.000002';
 $VERSION = eval $VERSION;
 
 use File::Spec;
+use IO::File;
 use version 0.87;
 BEGIN {
   if ($INC{'Log/Contextual.pm'}) {
@@ -84,7 +85,7 @@ sub new_from_module {
   my $compare_versions = sub {
     my ($v1, $op, $v2) = @_;
     $v1 = version->new($v1)
-      unless eval { $v1->isa('version') };
+      unless UNIVERSAL::isa($v1,'version');
   
     my $eval_str = "\$v1 $op \$v2";
     my $result   = eval $eval_str;
@@ -378,7 +379,7 @@ sub _parse_file {
   my $self = shift;
 
   my $filename = $self->{filename};
-  open( my $fh, '<', $filename )
+  my $fh = IO::File->new( $filename )
     or die( "Can't open '$filename': $!" );
 
   $self->_parse_fh($fh);
